@@ -1,6 +1,8 @@
 #ifndef GNU_EFI_ARM_SETJMP_H
 #define GNU_EFI_ARM_SETJMP_H
 
+#define JMPBUF_ALIGN 4
+
 typedef struct {
 	UINT32 R3; // A copy of R13
 	UINT32 R4;
@@ -14,6 +16,6 @@ typedef struct {
 	UINT32 R12;
 	UINT32 R13;
 	UINT32 R14;
-} __attribute__((__aligned__(4))) jmp_buf;
+} ALIGN(JMPBUF_ALIGN) jmp_buf;
 
 #endif /* GNU_EFI_ARM_SETJMP_H */
