@@ -16,6 +16,12 @@ Revision History
 
 --*/
 
+
+// Add a predefined macro to detect usage of the library
+#ifndef _GNU_EFI
+#define _GNU_EFI
+#endif
+
 //
 // Build flags on input
 //  EFI32
@@ -33,6 +39,7 @@ Revision History
 #define EFI_FIRMWARE_REVISION ((EFI_FIRMWARE_MAJOR_REVISION <<16) | (EFI_FIRMWARE_MINOR_REVISION))
 
 #include "efibind.h"
+#include "eficompiler.h"
 #include "efidef.h"
 #include "efidevp.h"
 #include "efipciio.h"
