@@ -208,6 +208,13 @@ EFIDebugVariable (
     VOID
     );
 
+VOID
+Exit(
+    IN EFI_STATUS   ExitStatus,
+    IN UINTN        ExitDataSize,
+    IN CHAR16       *ExitData OPTIONAL
+    );
+
 INTN
 GetShellArgcArgv(
     EFI_HANDLE ImageHandle,
@@ -306,17 +313,50 @@ StrCpy (
     IN CONST CHAR16    *Src
     );
 
+VOID
+StrnCpy (
+    IN CHAR16   *Dest,
+    IN CONST CHAR16    *Src,
+    IN UINTN     Len
+    );
+
+CHAR16 *
+StpCpy (
+    IN CHAR16   *Dest,
+    IN CONST CHAR16    *Src
+    );
+
+CHAR16 *
+StpnCpy (
+    IN CHAR16   *Dest,
+    IN CONST CHAR16    *Src,
+    IN UINTN     Len
+    );
+
 VOID
 StrCat (
     IN CHAR16   *Dest,
     IN CONST CHAR16   *Src
     );
 
+VOID
+StrnCat (
+    IN CHAR16   *Dest,
+    IN CONST CHAR16   *Src,
+    IN UINTN     Len
+    );
+
 UINTN
 StrLen (
     IN CONST CHAR16   *s1
     );
 
+UINTN
+StrnLen (
+    IN CONST CHAR16   *s1,
+    IN UINTN           Len
+    );
+
 UINTN
 StrSize (
     IN CONST CHAR16   *s1
