@@ -1,6 +1,8 @@
 #ifndef GNU_EFI_IA32_SETJMP_H
 #define GNU_EFI_IA32_SETJMP_H
 
+#define JMPBUF_ALIGN 4
+
 typedef struct {
 	UINT32	Ebx;
 	UINT32	Esi;
@@ -8,8 +10,6 @@ typedef struct {
 	UINT32	Ebp;
 	UINT32	Esp;
 	UINT32	Eip;
-} __attribute__((__aligned__(4))) jmp_buf;
-
-#define JMPBUF_ALIGN 4
+} ALIGN(JMPBUF_ALIGN) jmp_buf;
 
 #endif /* GNU_EFI_IA32_SETJMP_H */
