@@ -1005,6 +1005,7 @@ Routine Description:
     t       -   EFI time structure
     g       -   Pointer to GUID
     r       -   EFI status code (result code)
+    D       -   pointer to Device Path with normal ending.
 
     N       -   Set output attribute to normal
     H       -   Set output attribute to highlight
@@ -1131,6 +1132,9 @@ Returns:
             case 'X':
                 Item.Width = Item.Long ? 16 : 8;
                 Item.Pad = '0';
+#if __GNUC__ >= 7
+		__attribute__ ((fallthrough));
+#endif
             case 'x':
                 ValueToHex (
                     Item.Scratch,
@@ -1164,6 +1168,18 @@ Returns:
                 Item.Item.pw = Item.Scratch;
                 break;
 
+            case 'D':
+            {
+                EFI_DEVICE_PATH *dp = va_arg(ps->args, EFI_DEVICE_PATH *);
+                CHAR16 *dpstr = DevicePathToStr(dp);
+                StrnCpy(Item.Scratch, dpstr, PRINT_ITEM_BUFFER_LEN);
+                Item.Scratch[PRINT_ITEM_BUFFER_LEN-1] = L'\0';
+                FreePool(dpstr);
+
+                Item.Item.pw = Item.Scratch;
+                break;
+            }
+
             case 'f':
                 FloatToString (
                     Item.Scratch,
